@@ -1,15 +1,25 @@
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 import logging
 import struct
 
-import six
-
 from six.moves import xrange
 
 from monasca_common.kafka_lib.codec import (
     gzip_encode, gzip_decode, snappy_encode, snappy_decode
 )
 from monasca_common.kafka_lib.common import (
-    Message, OffsetAndMessage, TopicAndPartition,
+    Message, OffsetAndMessage,
     BrokerMetadata, TopicMetadata, PartitionMetadata,
     MetadataResponse, ProduceResponse, FetchResponse,
     OffsetResponse, OffsetCommitResponse, OffsetFetchResponse,
