@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -94,6 +95,17 @@ class TestConfluentKafkaProducer(base.BaseTestCase):
         self.prod.delivery_report(None, confluent_kafka.Message)
         mock_logger.debug.assert_called_once()
 
+    @mock.patch('monasca_common.confluent_kafka.producer.log')
+    @mock.patch('confluent_kafka.Message')
+    def test_delivery_report_with_unicode(self, mock_message, mock_logger):
+        mock_message.topic.return_value = 'test_topic'
+        mock_message.partition.return_value = '1'
+        mock_message.value.return_value = 'gęś'
+        self.prod.delivery_report(None, mock_message)
+        mock_logger.debug.assert_called_once_with('Message delivered to '
+                                                  'test_topic [1]: '
+                                                  'gęś')
+
 
 class TestConfluentKafkaConsumer(base.BaseTestCase):
 
@@ -101,8 +113,7 @@ class TestConfluentKafkaConsumer(base.BaseTestCase):
     def setUp(self, mock_confluent_consumer):
         super(TestConfluentKafkaConsumer, self).setUp()
         self.mock_confluent_consumer = mock_confluent_consumer
-        self.consumer = consumer.KafkaConsumer(['fake_server1',
-                                                'fake_server2'],
+        self.consumer = consumer.KafkaConsumer('fake_server1,fake_server2',
                                                'fake_group',
                                                FAKE_KAFKA_TOPIC, 128,
                                                'test_client',
@@ -124,8 +135,7 @@ class TestConfluentKafkaConsumer(base.BaseTestCase):
     def test_kafka_consumer_init(self):
         expected_config = {'group.id': 'fake_group',
                            'session.timeout.ms': 10000,
-                           'bootstrap.servers': ['fake_server1',
-                                                 'fake_server2'],
+                           'bootstrap.servers': 'fake_server1,fake_server2',
                            'fetch.min.bytes': 128,
                            'client.id': 'test_client',
                            'enable.auto.commit': False,
@@ -152,8 +162,12 @@ class TestConfluentKafkaConsumer(base.BaseTestCase):
             m.set_value("message{}".format(i))
             messages.append(m)
         self.consumer._consumer.poll.side_effect = messages
-        for index, message in enumerate(self.consumer):
-            self.assertEqual(message, messages[index])
+        try:
+            for index, message in enumerate(self.consumer):
+                self.assertEqual(message, messages[index])
+        except RuntimeError as re:
+            if 'generator raised StopIteration' in str(re):
+                pass
 
     @mock.patch('confluent_kafka.Message')
     @mock.patch('confluent_kafka.KafkaError')
